@@ -47,7 +47,7 @@ kaplan_meier_plot(result,
                   break.time.by="breakByQuarterYear",
                   xlab=".OS.months",
                   legend.title="ECOG Status",
-                  hazard.ratio=T,
+                  hazard.ratio=TRUE,
                   risk.table=TRUE,
                   table.layout="clean",
                   ggtheme=ggplot2::theme_bw(10))
@@ -56,7 +56,7 @@ kaplan_meier_plot(result,
 default_args <- list(break.time.by="breakByMonth",
                      xlab=".OS.months",
                      legend.title="ECOG Status",
-                     hazard.ratio=T,
+                     hazard.ratio=TRUE,
                      risk.table=TRUE,
                      table.layout="clean",
                      ggtheme=ggplot2::theme_bw(10))
